@@ -1,4 +1,4 @@
-# Copyright 2020 Cloudera Inc.
+# Copyright 2023 Cloudera Inc.
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
 # you may not use this file except in compliance with the License.
@@ -829,7 +829,7 @@ translations_indirect_generic_agg <- list(
     if (nargs() != 1) {
       stop("Function COUNT() requires one parameter", call. = FALSE)
     }
-    eval(substitute(quote(sum(!is.na(x)))))
+    eval(substitute(quote(sum(!is.na(x), na.rm = TRUE))))
   },
   max = function(x) {
     if (nargs() != 1) {
